var express = require('express');

var app = module.exports = express.createServer();

// Configuration

var staticTheme = require('../index');

app.configure(function(){
  app.set('views', __dirname + '/views');
  app.set('view engine', 'jade');
  app.use(express.bodyParser());
  app.use(express.cookieParser());
  app.use(express.session({ secret: "simyungk" }));
  app.use(express.methodOverride());
  
  app.use(function (req,res,next) {
    // set default theme
    if (!req.session.theme)
      req.session.theme = 'default';

    req.theme = req.session.theme;
    next();
  });

  /*
   *    - `defaultTheme`   Default theme name
   *    - `themeProp`   Theme session property name. ex) req.session.theme
   *    - `publicPath`   Relative public path from theme dir. 
   *    - `maxAge`   Browser cache maxAge in milliseconds. defaults to 0
   *    - `hidden`   Allow transfer of hidden files. defaults to false
   *    - `redirect`   Redirect to trailing "/" when the pathname is a dir
   */
  var options = {
      defaultTheme:'default'
    , themeProp:'theme'       // req.session.theme
    , publicPath:'public'
    , maxAge:86400000         // Browser cache maxAge
  };
  app.use(express.staticCache());
  app.use(staticTheme(__dirname+'/themes', options));
  app.use(app.router);
});

// Routes

app.get('/', function(req, res){
  res.render('index', {
      req: req
    , title: 'Static-theme example'
  });
});

app.get('/theme/swap', function(req, res){
  req.session.theme = (req.session.theme === 'default') ? 'black' : 'default';
  res.redirect('/');
});

app.listen(3000);
console.log("Express server listening on port %d in %s mode", app.address().port, app.settings.env);
